Skip to contents

A dataset associating the books and academic articles endeavouring to explain the US stagflation and their authors (Nodes_stagflation just takes the first author; here is the complete list of authors per document).

Usage

Authors_stagflation

Format

A data frame with 231 rows and 3 variables:

source_id

Identifier of the document published by the author

author_name

Author of the document

author_order

Author order in the document author list

Goutsmedt A. (2020) “From Stagflation to the Great Inflation: Explaining the 1970s US Economic Situation”. Revue d’Economie Politique, Forthcoming 2021.