Articles and Books Explaining the 1970s US Stagflation.
Source:R/Nodes_stagflation.R
Nodes_stagflation.RdA dataset containing the books and academic articles endeavouring to explain what happened in the US economy in the 1970s, as well as all the articles and books cited at least twice by the first set of articles and books (on the stagflation).
Format
A data frame with 654 rows and 7 variables:
- source_id
Identifier of the document
- source_author
Author of the document
- source_label
Use this as a label for nodes
- source_year
Year of publication of the document
- source_title
Title of the document
- source_journal
Journal of publication of the document (if an article)
- source_type
If "Stagflation", the document is listed as an explanation of the US stagflation. If "Non-Stagflation", the document is cited by a document explaining the stagflation